<?xml version="1.0" encoding="UTF-8"?>
<!--
Template: StateDiagram2SVG.xsl

Processes State Diagrams
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/2000/svg" xmlns:UML="org.omg.xmi.namespace.UML">
	<xsl:import href="../StateDiagrams/SimpleState.xsl" />
	<xsl:import href="../StateDiagrams/CompositeState.xsl" />
	<xsl:import href="../StateDiagrams/PseudoState.xsl"/>
	<xsl:import href="../StateDiagrams/FinalState.xsl"/>
	<xsl:import href="../StateDiagrams/SynchState.xsl"/>
	<xsl:import href="../StateDiagrams/State.xsl" />
	<xsl:import href="../Common/Comment.xsl" />
	<xsl:import href="../Common/Lines.xsl" />
	<xsl:import href="../Common/Ellipse.xsl" />
	<xsl:import href="../Common/Polyline.xsl" />
	<xsl:import href="../Common/FreeText.xsl" />
	<xsl:output media-type="image/svg+xml" method="xml" indent="yes"/>

	<!-- StateDiagram -->
	<xsl:template match="*[UML:GraphElement.semanticModel/UML:SimpleSemanticModelElement/@typeInfo = 'StateDiagram']">
		
		<title><xsl:value-of select="@name"/></title>
		<desc>State diagram</desc>
		
		<!-- Contained nodes -->
		<xsl:for-each select="UML:GraphElement.contained/*">
			<xsl:choose>
				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML:Pseudostate">
					<xsl:call-template name="PseudoState" />
				</xsl:when>
				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML:FinalState">
					<xsl:call-template name="FinalState" />
				</xsl:when>
				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML:SynchState">
					<xsl:call-template name="SynchState" />
				</xsl:when>
				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML:SimpleState">
					<xsl:call-template name="SimpleState" />
				</xsl:when>
				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML:CompositeState">
					<xsl:call-template name="CompositeState" />
				</xsl:when>
				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML:Comment">
					<xsl:call-template name="Comment" />
				</xsl:when>
				<xsl:when test="UML:GraphElement.semanticModel/UML:SimpleSemanticModelElement/@typeInfo = 'FreeText'">
					<xsl:call-template name="FreeText" />
				</xsl:when>

				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML:Transition">
					<xsl:call-template name="Transition_Line"/>
				</xsl:when>
				<xsl:when test="UML:GraphElement.semanticModel/UML:SimpleSemanticModelElement/@typeInfo = 'CommentLink'">
					<xsl:call-template name="Comment_Line"/>
				</xsl:when>

				<xsl:when test="self::UML:Ellipse">
					<xsl:call-template name="Ellipse"/>
				</xsl:when>
				<xsl:when test="self::UML:Polyline">
					<xsl:call-template name="Polyline"/>
				</xsl:when>
				
				<xsl:when test="namespace-uri(../../UML:Diagram.owner/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/*) = 'org.omg.xmi.namespace.UML2' and UML:GraphElement.semanticModel/UML:SimpleSemanticModelElement/@typeInfo = 'NameCompartment'">
					<xsl:call-template name="NameCompartment">
						<xsl:with-param name="OwnerSemanticID" select="../../@xmi.id"/>
					</xsl:call-template>
				</xsl:when>

				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML2:State">
					<xsl:call-template name="State" />
				</xsl:when>
				
				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML2:Transition">
					<xsl:call-template name="Transition_Line"/>
				</xsl:when>

				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML2:FinalState">
					<xsl:call-template name="FinalState" />
				</xsl:when>

				<xsl:when test="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML2:Pseudostate">
					<xsl:call-template name="PseudoState" />
				</xsl:when>
				
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>