<?xml version="1.0" encoding="UTF-8"?>
<!--
Template: ExtensionPoint.xsl

Displays use case extension point descriptions.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/2000/svg" xmlns:UML="org.omg.xmi.namespace.UML">
	<xsl:import href="../Common/Globals.xsl"/>
	<xsl:import href="../Common/Styling.xsl"/>
	<xsl:import href="../Common/Text.xsl"/>
	<xsl:output media-type="image/svg+xml" method="xml" indent="yes"/>

	<!-- ExtensionPoint -->
	<xsl:template name="ExtensionPoint">

		<xsl:variable name="SemanticID" select="UML:GraphElement.semanticModel/UML:Uml1SemanticModelBridge/UML:Uml1SemanticModelBridge.element/UML:ExtensionPoint/@xmi.idref"/>

		<!-- Main ExtensionPoint group -->
		<g id="{@xmi.id}" transform="translate({UML:GraphElement.position/XMI.field[1]}, {UML:GraphElement.position/XMI.field[2]})">
			<xsl:apply-templates select="." mode="FontStyle"/>
			<xsl:apply-templates select="." mode="StrokeStyle"/>
			<xsl:apply-templates select="." mode="isVisible"/>

			<title><xsl:value-of select="key('xmi.id', $SemanticID)/@name"/></title>
			<desc><xsl:text>ExtensionPoint</xsl:text></desc>

			<!-- ExtensionPoint text -->
			<xsl:for-each select="UML:GraphElement.contained/UML:GraphNode">
				<xsl:choose>
					<xsl:when test="UML:GraphElement.semanticModel/UML:SimpleSemanticModelElement/@typeInfo = 'Name'">
						<!-- Extension name -->
						<xsl:call-template name="Text">
							<xsl:with-param name="String" select="key('xmi.id', $SemanticID)/@name"/>
						</xsl:call-template>
					</xsl:when>

					<xsl:when test="UML:GraphElement.semanticModel/UML:SimpleSemanticModelElement/@typeInfo = 'NameLocationSeparator'">
						<!-- Extension name<->location separator, ':' -->
						<xsl:call-template name="Text">
							<xsl:with-param name="String" select="$NameLocationSeparator" />
						</xsl:call-template>
					</xsl:when>

					<xsl:when test="UML:GraphElement.semanticModel/UML:SimpleSemanticModelElement/@typeInfo = 'Location'">
						<!-- Extension location -->
						<xsl:call-template name="Text">
							<xsl:with-param name="String" select="key('xmi.id', $SemanticID)/@location"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</g>
	</xsl:template>
</xsl:stylesheet>
